@@ -19,6 +19,7 @@ from python_kemptech_api.exceptions import (
     LoadMasterParameterError,
     ValidationError,
     SubVsCannotCreateSubVs,
+    BackupFailed,
 )
 from .utils import (
     validate_port,
@@ -410,8 +411,12 @@ class LoadMaster(HttpClient):
         file_name = "backups/{}.backup".format(self.ip_address)
 
         with open(file_name, 'wb') as file:
-            curl = ['curl', '-k', '{}/backup'.format(self.endpoint)]
+            curl = ['curl', '-k', '--connect-timeout', '5', '{}/backup'.format(
+                    self.endpoint)]
             subprocess.call(curl, stdout=file)
+            file.seek(0, 2)
+            if file.tell() == 0:
+                raise BackupFailed(self.ip_address)
         return file_name
 
     def alsi_license(self, kemp_id, password):
